pub struct GGScore {
pub display_value: Option<String>,
pub label: Option<String>,
pub value: Option<f64>,
}Expand description
Equivalent for start.gg Score.
Each element in the structure is optional, allowing a user to only query values they want. Given each is an option and not a requirement, a method is included for each element with the same name. These methods will unwrap and return the proper value without any unwrapping or references needed.
Fields
display_value: Option<String>label: Option<String>value: Option<f64>Implementations