pub struct GGStage {
pub id: Option<i64>,
pub name: Option<String>,
}Expand description
Equivalent for start.gg Stage.
Each element in the structure is optional, allowing a user to only query values they want. Given each is an option and not a requirement, a method is included for each element with the same name. These methods will unwrap and return the proper value without any unwrapping or references needed.
Fields
id: Option<i64>name: Option<String>Implementations